==> apache-shardingsphere-5.5.2-src.zip: apache-shardingsphere-5.5.2-src-release/kernel/sql-translator/core/src/main/java/org/apache/shardingsphere/sqltranslator/rule/builder/DefaultSQLTranslatorRuleConfigurationBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sqltranslator.rule.builder;

import org.apache.shardingsphere.infra.rule.builder.global.DefaultGlobalRuleConfigurationBuilder;
import org.apache.shardingsphere.sqltranslator.config.SQLTranslatorRuleConfiguration;
import org.apache.shardingsphere.sqltranslator.constant.SQLTranslatorOrder;

import java.util.Properties;

/**
 * Default SQL translator rule configuration builder.
 */
public final class DefaultSQLTranslatorRuleConfigurationBuilder implements DefaultGlobalRuleConfigurationBuilder<SQLTranslatorRuleConfiguration, SQLTranslatorRuleBuilder> {
    
    @Override
    public SQLTranslatorRuleConfiguration build() {
        return new SQLTranslatorRuleConfiguration("NATIVE", new Properties(), true);
    }
    
    @Override
    public int getOrder() {
        return SQLTranslatorOrder.ORDER;
    }
    
    @Override
    public Class<SQLTranslatorRuleBuilder> getTypeClass() {
        return SQLTranslatorRuleBuilder.class;
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/kernel/sql-translator/core/src/main/java/org/apache/shardingsphere/sqltranslator/rule/builder/DefaultSQLTranslatorRuleConfigurationBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.sqltranslator.rule.builder;

import org.apache.shardingsphere.infra.rule.builder.global.DefaultGlobalRuleConfigurationBuilder;
import org.apache.shardingsphere.sqltranslator.config.SQLTranslatorRuleConfiguration;
import org.apache.shardingsphere.sqltranslator.constant.SQLTranslatorOrder;

import java.util.Properties;

/**
 * Default SQL translator rule configuration builder.
 */
public final class DefaultSQLTranslatorRuleConfigurationBuilder implements DefaultGlobalRuleConfigurationBuilder<SQLTranslatorRuleConfiguration, SQLTranslatorRuleBuilder> {
    
    @Override
    public SQLTranslatorRuleConfiguration build() {
        return new SQLTranslatorRuleConfiguration(null, new Properties(), true);
    }
    
    @Override
    public int getOrder() {
        return SQLTranslatorOrder.ORDER;
    }
    
    @Override
    public Class<SQLTranslatorRuleBuilder> getTypeClass() {
        return SQLTranslatorRuleBuilder.class;
    }
}
